module AccountsManagement
  class Documents::Contract < ActiveRecord::Base
    belongs_to :parent_contract, class_name: 'AccountsManagement::Documents::Contract', optional: true
    belongs_to :status, class_name: 'AccountsManagement::Documents::ContractStatus', optional: true

    belongs_to :first_party, polymorphic: true
    belongs_to :first_party_account, class_name: 'AccountsManagement::Ledgers::Account'
    belongs_to :second_party, polymorphic: true
    belongs_to :second_party_account, class_name: 'AccountsManagement::Ledgers::Account'

    belongs_to :currency, class_name: 'CoreModels::Base::Currency'

    belongs_to :recurring_fee_interval_unit, class_name: 'CoreModels::Base::Timespan', optional: true
    belongs_to :billing_interval_unit, class_name: 'CoreModels::Base::Timespan', optional: true

    belongs_to :owner_user, polymorphic: true, optional: true

    belongs_to :project, polymorphic: true, optional: true

    has_many :contract_line_items, class_name: 'AccountsManagement::Documents::ContractLineItem', dependent: :destroy
    accepts_nested_attributes_for :contract_line_items

    has_many :contract_attachments, class_name: 'AccountsManagement::Documents::ContractAttachment', dependent: :destroy
    accepts_nested_attributes_for :contract_attachments
    has_many :attachments, through: :contract_attachments, class_name: 'AssetManagement::AssetData', dependent: :destroy
    accepts_nested_attributes_for :attachments

    # attr_accessible :name, :major_version, :minor_version, :is_active, :detail
    # attr_accessible :expected_start_date, :expected_end_date, :actual_start_date, :actual_end_date
    # attr_accessible :billing_interval_count, :billing_interval_ical_expression
    # attr_accessible :first_party_reference_number, :second_party_reference_number, :fixed_price
    # attr_accessible :minimum_duration_days
    # attr_accessible :recurring_fee, :recurring_fee_ical_expression,:recurring_fee_interval_count
    # attr_accessible :service_level_agreement, :terms_and_conditions

    # attr_accessible :parent_contract, :parent_contract_id
    # attr_accessible :status, :status_id
    # attr_accessible :first_party, :first_party_id
    # attr_accessible :first_party_account, :first_party_account_id
    # attr_accessible :second_party, :second_party_id
    # attr_accessible :second_party_account, :second_party_account_id
    # attr_accessible :currency, :currency_id
    # attr_accessible :project, :project_id
    # attr_accessible :owner_user, :owner_user_id

    # attr_accessible :recurring_fee_interval_unit, :recurring_fee_interval_unit_id
    # attr_accessible :billing_interval_unit, :billing_interval_unit_id

    # attr_accessible :contract_attachments, :contract_attachments_attributes

    # attr_accessible :owner_user_type, :first_party_type, :second_party_type, :project_type

    validates :name, :major_version, :minor_version, presence: true
    # validates :first_party, presence: true
    # validates :second_party, presence: true
    # validates :currency, presence: true

    #---------------------------------------------------------------------------

    def to_s
      "#{name} (#{version_s})"
    end

    def version_s
      "#{major_version}.#{minor_version}"
    end

    def version
      version_s.to_f
    end
  end
end
