# For the definition of ContractLineItem/ContractLineItemNumber,
# see doc/SUBPART_204.71-UNIFORM_CONTRACT_LINE_ITEM_NUMBERING_SYSTEM.html
# ORIGINAL URL: http://www.acq.osd.mil/dpap/dars/dfars/html/current/204_71.htm

module AccountsManagement
  class Documents::ContractLineItem < ActiveRecord::Base
    belongs_to :contract, class_name: 'AccountsManagement::Documents::Contract'
    belongs_to :product, polymorphic: true
    belongs_to :currency, class_name: 'CoreModels::Base::Currency'
    belongs_to :recurring_fee_interval_unit, class_name: 'CoreModels::Base::Timespan', optional: true
    belongs_to :billing_interval_unit, class_name: 'CoreModels::Base::Timespan', optional: true

    has_many :contract_line_item_rates, class_name: 'AccountsManagement::Documents::ContractLineItemRate'
    accepts_nested_attributes_for :contract_line_item_rates, allow_destroy: true
    # attr_accessible :contract_line_item_rates, :contract_line_item_rates_attributes

    #---------------------------------------------------------------------------

    # attr_accessible :first_party_clin
    # attr_accessible :second_party_clin
    # attr_accessible :quantity, :description, :fixed_price
    # attr_accessible :recurring_fee, :recurring_fee_ical_expression, :recurring_fee_interval_count
    # attr_accessible :recurring_fee_interval_unit, :recurring_fee_interval_unit_id
    # attr_accessible :billing_interval_count, :billing_interval_ical_expression
    # attr_accessible :billing_interval_unit, :billing_interval_unit_id
    # attr_accessible :expected_start_date, :expected_end_date, :actual_start_date, :actual_end_date
    # attr_accessible :is_active, :minimum_duration_days
    # attr_accessible :note

    # attr_accessible :contract, :contract_id
    # attr_accessible :product, :product_id
    # attr_accessible :product_type
    # attr_accessible :currency, :currency_id

    #---------------------------------------------------------------------------

    validates :contract, presence: true
    validates :quantity, presence: true, numericality: true
    validates :currency, presence: true

    validate :valid_clin
    validate :valid_product_or_description

    #---------------------------------------------------------------------------

    def to_s
      "#{first_party_clin.presence || second_party_clin} - #{quantity} x " + (product ? "#{product}" : "#{description}")
    end

    #---------------------------------------------------------------------------

    private

    def valid_clin
      return unless (first_party_clin.nil? || first_party_clin.empty?) && (second_party_clin.nil? || second_party_clin.empty?)

      errors[:base] << "Specify a valid CLIN reference"
    end

    def valid_product_or_description
      errors[:base] << "Specify a product and/or a description" if product.nil? && description.empty?
    end
  end
end
