module AccountsManagement
  class Documents::InvoiceEntry < ActiveRecord::Base
    belongs_to :invoice, class_name: 'AccountsManagement::Documents::Invoice'
    belongs_to :invoice_entry_type, class_name: 'AccountsManagement::Documents::InvoiceEntryType', optional: true
    belongs_to :product, polymorphic: true, optional: true
    belongs_to :currency, class_name: 'CoreModels::Base::Currency'

    # attr_accessible :quantity, :description, :unit_price, :net_price

    # attr_accessible :invoice, :invoice_id
    # attr_accessible :invoice_entry_type, :invoice_entry_type_id
    # attr_accessible :product, :product_id
    # attr_accessible :currency, :currency_id

    # validates :invoice, presence: true
    validates :quantity, presence: true, numericality: true
    validates :unit_price, presence: true, numericality: true
    validates :currency, presence: true

    validate :valid_product_or_description

    #---------------------------------------------------------------------------

    def to_s
      "#{quantity} x " + (product ? "#{product}" : "#{description}")
    end

    #---------------------------------------------------------------------------

    private

    def valid_product_or_description
      errors[:base] << "must have a product and/or a description" if product.nil? && description.blank?
    end
  end
end
