module AccountsManagement
  class Ledgers::Account < ActiveRecord::Base
    belongs_to :owner, polymorphic: true # Usually a Person or a Company
    belongs_to :default_currency, class_name: 'CoreModels::Base::Currency'

    has_one :master_data, class_name: 'AccountsManagement::Ledgers::MasterData', dependent: :destroy
    accepts_nested_attributes_for :master_data

    has_many :ledgers, class_name: 'AccountsManagement::Ledgers::Ledger', inverse_of: :account, dependent: :destroy
    accepts_nested_attributes_for :ledgers

    has_many :invoice_or_purchase_order_templates, class_name: 'AssetManagement::AssetData', as: :asset_owner, dependent: :destroy
    accepts_nested_attributes_for :invoice_or_purchase_order_templates, allow_destroy: true

    # attr_accessible :owner, :owner_id
    # attr_accessible :default_currency, :default_currency_id
    # attr_accessible :name, :convert_all_transactions

    # validates :owner, presence: true # rubocop(Rails/RedundantPresenceValidationOnBelongsTo)
    validates :name, presence: true
    # validates :default_currency, presence: true # rubocop(Rails/RedundantPresenceValidationOnBelongsTo)

    #---------------------------------------------------------------------------
    # Callbacks

    # Create a General ledger
    # after_create lambda {
    #   ledgers.create!(
    #     name: 'General',
    #     currency: default_currency
    #   )
    # }

    #---------------------------------------------------------------------------

    def to_s
      unique_name
    end

    def unique_name
      owner.nil? ? name : "#{name} (#{owner.display_name})"
    end

    #---------------------------------------------------------------------------
  end
end
