module AccountsManagement
  class Ledgers::LedgerEntry < ActiveRecord::Base
    DIRECTION = [:credit, :debit].freeze

    belongs_to :primary_ledger, class_name: 'AccountsManagement::Ledgers::Ledger', inverse_of: :ledger_entries
    belongs_to :payment_method, class_name: 'CoreModels::Base::PaymentMethod'
    belongs_to :currency, class_name: 'CoreModels::Base::Currency'
    belongs_to :secondary_ledger, class_name: 'AccountsManagement::Ledgers::Ledger'
    belongs_to :invoice, class_name: 'AccountsManagement::Documents::Invoice', optional: true
    belongs_to :order, class_name: 'AccountsManagement::Documents::Order', optional: true

    # attr_accessible :date, :description
    # attr_accessible :direction, :amount, :vat_amount

    # attr_accessible :payment_method, :payment_method_id
    # attr_accessible :currency, :currency_id
    # attr_accessible :invoice, :invoice_id
    # attr_accessible :order, :order_id

    validates :direction, presence: true
    validates :direction, inclusion: { in: DIRECTION }

    validates :date, presence: true
    validates :amount, presence: true

    # validates :currency, presence: true # rubocop(Rails/RedundantPresenceValidationOnBelongsTo)

    # validates :secondary_ledger, presence: true # rubocop(Rails/RedundantPresenceValidationOnBelongsTo)

    #---------------------------------------------------------------------------
    # Used in double entry book-keeping handler in after_create to avoid recursion

    attr_accessor :avoid_recursion

    #---------------------------------------------------------------------------
    # Callbacks

    after_commit :double_entry_book_keeping_handler, on: :create

    def double_entry_book_keeping_handler
      return if avoid_recursion.present?

      # Double entry book-keeping
      target_ledger = secondary_ledger
      entry = target_ledger.ledger_entries.new(attributes.except('id', 'created_at', 'updated_at'))
      entry.primary_ledger = secondary_ledger
      entry.secondary_ledger = primary_ledger
      entry.direction = direction.eql?(:debit) ? :credit : :debit
      entry.avoid_recursion = true
      entry.save!

      # Double-double entry book-keeping (duplicate transaction in our General ledeger)
      # target_ledger = primary_ledger.account.ledgers.find_by(name: 'General')
      # entry = target_ledger.ledger_entries.new(attributes.except('id', 'created_at', 'updated_at'))
      # entry.avoid_recursion = true
      # entry.save!
    end

    #---------------------------------------------------------------------------

    def direction
      read_attribute(:direction)&.to_sym
    end

    def direction=(value)
      write_attribute(:direction, value.to_s)
    end

    #---------------------------------------------------------------------------

    def to_s
      "#{date} - #{direction} #{description} #{amount} #{currency}"
    end

    #---------------------------------------------------------------------------
  end
end
