class CreateAccountsManagementDocumentsOrders < ActiveRecord::Migration[4.2]
  def change
    create_table :accounts_management_documents_orders do |t|
      t.references :owner, polymorphic: true
      t.references :owner_account
      t.references :client_account
      t.string :reference_number
      t.string :client_purchase_order_reference
      t.boolean :is_active, default: true
      t.boolean :is_complete, default: false
      t.datetime :order_date
      t.datetime :required_delivery_date
      t.datetime :date_shipped
      t.datetime :expected_delivery_date
      t.datetime :actual_delivery_date
      t.datetime :expected_payment_date
      t.datetime :actual_payment_date
      t.float :quote_amount, precision: 20, scale: 2
      t.references :vat_rate
      t.float :freight_charge, precision: 20, scale: 2
      t.references :currency
      t.string :payment_terms
      t.string :shipped_via
      t.string :shipping_method
      t.references :alternate_shipping_address
      t.references :salesperson
      t.text :additional_notes

      t.timestamps null: false
    end

    add_index :accounts_management_documents_orders, [:owner_id, :owner_type], name: :index_on_orders_on_owner
    add_index :accounts_management_documents_orders, :owner_account_id, name: :index_on_orders_on_owner_account
    add_index :accounts_management_documents_orders, :client_account_id, name: :index_on_orders_on_client_account
    add_index :accounts_management_documents_orders, :vat_rate_id, name: :index_on_orders_on_vat_rate_id
    add_index :accounts_management_documents_orders, :currency_id, name: :index_on_orders_on_currency_id
    add_index :accounts_management_documents_orders, :alternate_shipping_address_id,
              name: :index_on_orders_on_alternate_shipping_address_id
    add_index :accounts_management_documents_orders, :salesperson_id, name: :index_on_orders_on_salesperson_id
    add_index :accounts_management_documents_orders, :expected_payment_date, name: :index_on_orders_on_expected_payment_date
  end
end
